OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, selecione um arquivo.",
    "File is too big" : "O arquivo é muito grande",
    "The selected file is not an image." : "O arquivo selecionado não é uma imagem",
    "The selected file cannot be read." : "O arquivo selecionado não pôde ser lido",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize em php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE que foi especificada no formulário HTML",
    "The file was only partially uploaded" : "O arquivo foi carregado apenas parcialmente",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível gravar o arquivo no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP interrompeu o upload do arquivo",
    "Invalid file provided" : "Arquivo fornecido inválido",
    "No image or file provided" : "Nenhuma imagem ou arquivo fornecido",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Entre em contato com o administrador.",
    "Invalid image" : "Imagem inválida",
    "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
    "No crop data provided" : "Nenhum dado recortado fornecido",
    "No valid crop data provided" : "Nenhum dado recortado válido",
    "Crop is not square" : "Recorte não é quadrado",
    "State token does not match" : "O estado do token não coincide",
    "Invalid app password" : "Senha do aplicativo inválida",
    "Could not complete login" : "Não foi possível concluir o login",
    "State token missing" : "State token missing",
    "Your login token is invalid or has expired" : "Seu token de login é inválido ou expirou",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versão da comunidade do Nextcloud não é compatível e as notificações por push são limitadas.",
    "Login" : "Entrar",
    "Unsupported email length (>255)" : "Comprimento de e-mail não suportado (>255)",
    "Password reset is disabled" : "A redefinição de senha está desabilitada",
    "Could not reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
    "Could not reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
    "Password is too long. Maximum allowed length is 469 characters." : "A senha é muito longa. O comprimento máximo permitido é de 469 caracteres.",
    "%s password reset" : "%s redefinir senha",
    "Password reset" : "Redefinir a senha",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no botão abaixo para redefinir sua senha. Se você não solicitou isso, ignore este e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no link abaixo para redefinir sua senha. Se você não solicitou isso, ignore este e-mail.",
    "Reset your password" : "Redefinir sua senha",
    "The given provider is not available" : "O provedor fornecido não está disponível",
    "Task not found" : "Tarefa não encontrada",
    "Internal error" : "Erro interno",
    "Not found" : "Não encontrado",
    "Bad request" : "Pedido ruim",
    "Requested task type does not exist" : "O tipo de tarefa solicitada não existe",
    "Necessary language model provider is not available" : "O provedor de modelo de idioma necessário não está disponível",
    "No text to image provider is available" : "Nenhum provedor de texto para imagem está disponível",
    "Image not found" : "Imagem não encontrada",
    "No translation provider available" : "Nenhum provedor de tradução disponível",
    "Could not detect language" : "Não foi possível detectar o idioma",
    "Unable to translate" : "Incapaz de traduzir",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "Alguns dos seus compartilhamentos por link foram removidos",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a um bug de segurança, tivemos que remover alguns dos seus compartilhamentos por link. Por favor, veja o link para mais informações.",
    "The account limit of this instance is reached." : "O limite de contas desta instância foi atingido.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Digite sua chave de assinatura no aplicativo de suporte para aumentar o limite da conta. Isso também concede a você todos os benefícios adicionais que o Nextcloud Enterprise oferece e é altamente recomendado para operações em empresas.",
    "Learn more ↗" : "Saiba mais ↗",
    "Preparing update" : "Preparando a atualização",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Etapa do reparo:",
    "Repair info:" : "Informação do reparo:",
    "Repair warning:" : "Aviso do reparo:",
    "Repair error:" : "Erro do reparo:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
    "Turned on maintenance mode" : "Ativar o modo de manutenção",
    "Turned off maintenance mode" : "Desativar o modo de manutenção",
    "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
    "Updating database schema" : "Atualizando o schema do banco de dados",
    "Updated database" : "Atualizar o banco de dados",
    "Update app \"%s\" from App Store" : "Atualizar aplicativo \"%s\" da App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando se o schema do banco de dados para %s pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
    "Updated \"%1$s\" to %2$s" : "Atualizou \"%1$s\" para %2$s",
    "Set log level to debug" : "Definir o nível de log para debug",
    "Reset log level" : "Redefinir o nível do log",
    "Starting code integrity check" : "Inicializando a verificação da integridade do código",
    "Finished code integrity check" : "Finalizada a verificação de integridade do código",
    "%s (incompatible)" : "%s (incompatível)",
    "The following apps have been disabled: %s" : "Os seguintes aplicativos foram desativados: %s",
    "Already up to date" : "Já está atualizado",
    "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
    "unknown text" : "texto desconhecido",
    "Hello world!" : "Olá mundo!",
    "sunny" : "ensolarado",
    "Hello {name}, the weather is {weather}" : "Olá {name}, o clima está {weather}",
    "Hello {name}" : "Olá {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes são os resultados de sua pesquisa<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n arquivos","baixar %n arquivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento. Em alguns ambientes, se sair desta página o processo poderá ser interrompido.",
    "Update to {version}" : "Atualizar para {version}",
    "An error occurred." : "Ocorreu um erro.",
    "Please reload the page." : "Por favor recarregue a página",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi realizada com sucesso. Para mais informações <a href=\"{url}\">verifique nosso post no fórum</a> que abrange esta questão.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
    "Continue to {productName}" : "Continuar para {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
    "Applications menu" : "Menu de aplicativos",
    "Apps" : "Aplicativos",
    "More apps" : "Mais aplicativos",
    "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} notificações","{count} notificações"],
    "No" : "Não",
    "Yes" : "Sim",
    "The remote URL must include the user." : "A URL remota deve incluir o usuário.",
    "Invalid remote URL." : "URL remota inválida.",
    "Failed to add the public link to your Nextcloud" : "Ocorreu uma falha ao adicionar o link público ao seu Nextcloud",
    "Federated user" : "Usuário federado",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Criar compartilhamento",
    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
    "Please copy the link manually:" : "Copie o link manualmente:",
    "Custom date range" : "Data personalizada",
    "Pick start date" : "Escolha uma data de início",
    "Pick end date" : "Escolha uma data de fim",
    "Search in date range" : "Pesquise em um intervalo de data",
    "Search in current app" : "Pesquisar no aplicativo atual",
    "Clear search" : "Limpar pesquisa",
    "Search everywhere" : "Pesquise em qualquer lugar",
    "Searching …" : "Pesquisando...",
    "Start typing to search" : "Comece a digitar para pesquisar",
    "No matching results" : "Nenhum resultado encontrado",
    "Today" : "Hoje",
    "Last 7 days" : "Últimos 7 dias",
    "Last 30 days" : "Últimos 30 dias",
    "This year" : "Este ano",
    "Last year" : "Último ano",
    "Unified search" : "Pesquisa unificada",
    "Search apps, files, tags, messages" : "Procure por apps, arquivos, etiquetas, mensagens",
    "Places" : "Lugares",
    "Date" : "Data",
    "Search people" : "Procure pessoas",
    "People" : "Pessoas",
    "Filter in current view" : "Filtrar na visualização atual",
    "Results" : "Resultados",
    "Load more results" : "Carregar mais resultados",
    "Search in" : "Procurar em",
    "Log in" : "Entrar",
    "Logging in …" : "Entrando...",
    "Log in to {productName}" : "Faça login em {productName}",
    "Wrong login or password." : "Login ou senha incorretos.",
    "This account is disabled" : "Essa conta está desativada",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos várias tentativas de login inválidas de seu IP. Portanto, seu próximo login será desacelerado em até 30 segundos.",
    "Account name or email" : "Nome da conta ou e-mail",
    "Account name" : "Nome da conta",
    "Server side authentication failed!" : "Autenticação do servidor falhou!",
    "Please contact your administrator." : "Por favor, entre em contato com o administrador.",
    "Temporary error" : "Erro temporário",
    "Please try again." : "Por favor, tente novamente.",
    "An internal error occurred." : "Ocorreu um erro interno.",
    "Please try again or contact your administrator." : "Tente novamente ou entre em contato com o administrador.",
    "Password" : "Senha",
    "Log in with a device" : "Logar-se com um dispositivo",
    "Login or email" : "Login ou e-mail",
    "Your account is not setup for passwordless login." : "Sua conta não está configurada para login sem senha.",
    "Your connection is not secure" : "Sua conexão não é segura",
    "Passwordless authentication is only available over a secure connection." : "A autenticação sem senha está disponível apenas em uma conexão segura.",
    "Browser not supported" : "Navegador não suportado",
    "Passwordless authentication is not supported in your browser." : "A autenticação sem senha não é suportada no seu navegador.",
    "Reset password" : "Redefinir senha",
    "Back to login" : "Voltar ao login",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se essa conta existir, uma mensagem de redefinição de senha foi enviada para o endereço de e-mail associado a ela. Se você não receber, verifique seu endereço de e-mail e/ou faça login, confira suas pastas de spam/lixeira ou peça ajuda à administração local.",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar o e-mail de redefinição. Por favor, contate o administrador.",
    "Password cannot be changed. Please contact your administrator." : "A senha não pôde ser alterada. Por favor contate seu administrador.",
    "New password" : "Nova senha",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Seus arquivos são criptografados. Não há como recuperar os dados depois que a senha for redefinida. Se não tiver certeza do que fazer, entre em contato com o administrador. Quer realmente continuar?",
    "I know what I'm doing" : "Eu sei o que estou fazendo",
    "Resetting password" : "Redefinindo a senha",
    "Schedule work & meetings, synced with all your devices." : "Programe trabalhos e reuniões, sincronizados com seus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha seus colegas e amigos em um só lugar sem vazar informações particulares.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicativo de e-mail simples e bem integrado com Arquivos, Contatos e Calendário.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões online e conferência na web - no seu navegador e com aplicativos móveis.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, planilhas e apresentações, construídos no Collabora Online.",
    "Distraction free note taking app." : "Distraction free note taking app.",
    "Recommended apps" : "Aplicativos recomendados",
    "Loading apps …" : "Carregando aplicativos...",
    "Could not fetch list of apps from the App Store." : "Não foi possível buscar a lista de aplicativos na App Store.",
    "App download or installation failed" : "O download ou a instalação do aplicativo falhou",
    "Cannot install this app because it is not compatible" : "Não foi possível instalar este aplicativo pois não é compatível.",
    "Cannot install this app" : "Não foi possível instalar este aplicativo.",
    "Skip" : "Ignorar",
    "Installing apps …" : "Instalando aplicativos...",
    "Install recommended apps" : "Instalar aplicativos recomendados",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Menu de configurações",
    "Loading your contacts …" : "Carregando seus contatos...",
    "Looking for {term} …" : "Procurando por {term}…",
    "Search contacts" : "Pesquisar contatos",
    "Reset search" : "Redefinir pesquisa",
    "Search contacts …" : "Procurar contatos...",
    "Could not load your contacts" : "Não foi possível carregar seus contatos",
    "No contacts found" : "Nenhum contato encontrado",
    "Show all contacts" : "Mostrar todos os contatos",
    "Install the Contacts app" : "Instalar o aplicativo Contatos",
    "Search" : "Pesquisar",
    "No results for {query}" : "Sem resultados para {query}",
    "Press Enter to start searching" : "Pressione Enter para iniciar a pesquisa",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digite {minSearchLength} caractere ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar"],
    "An error occurred while searching for {type}" : "Ocorreu um erro ao pesquisar por {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "A pesquisa iniciará assim que você começar a digitar e os resultados você pode navegar com as setas do teclado",
    "Search for {name} only" : "Pesquisar somente por {name}",
    "Loading more results …" : "Carregando mais resultados…",
    "Forgot password?" : "Esqueceu a senha?",
    "Back to login form" : "Voltar ao formulário de login",
    "Back" : "Voltar",
    "Login form is disabled." : "O formulário de login está desativado.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
    "More actions" : "Mais ações",
    "Security warning" : "Alerta de segurança",
    "Storage & database" : "Armazenamento & banco de dados",
    "Data folder" : "Pasta de dados",
    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos adicionais do PHP para escolher outros tipos de banco de dados.",
    "For more details check out the documentation." : "Para mais informações consulte a documentação.",
    "Performance warning" : "Alerta de performance",
    "You chose SQLite as database." : "Você escolheu o SQLite como banco de dados.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "O SQLite deve ser usado apenas para instâncias mínimas e de desenvolvimento. Para produção, recomendamos um banco de dados diferente.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se você usa clientes para sincronização de arquivos, o SQLite é altamente desencorajado.",
    "Database user" : "Usuário do banco de dados",
    "Database password" : "Senha do banco de dados",
    "Database name" : "Nome do banco de dados",
    "Database tablespace" : "Espaço de tabela do banco de dados",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique o nome do host e porta (ex., localhost:5432).",
    "Database host" : "Host do banco de dados",
    "Installing …" : "Instalando ...",
    "Install" : "Instalar",
    "Need help?" : "Precisa de ajuda?",
    "See the documentation" : "Veja a documentação",
    "{name} version {version} and above" : "{name} versão {version} e superior",
    "This browser is not supported" : "Este navegador não é compatível",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é suportado. Atualize para uma versão mais recente ou compatível.",
    "Continue with this unsupported browser" : "Continuar com este navegador não compatível",
    "Supported versions" : "Versões compatíveis",
    "Search {types} …" : "Pesquisar {types}…",
    "Choose {file}" : "Escolher {file}",
    "Choose" : "Escolher",
    "Copy to {target}" : "Copiar para {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover para {target}",
    "Move" : "Mover",
    "OK" : "OK",
    "read-only" : "somente leitura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de arquivo","{count} arquivo conflita","{count} arquivo conflita"],
    "One file conflict" : "Conflito em um arquivo",
    "New Files" : "Novos arquivos",
    "Already existing files" : "Arquivos já existentes",
    "Which files do you want to keep?" : "Quais arquivos você quer manter?",
    "If you select both versions, the copied file will have a number added to its name." : "Se você selecionar ambas as versões, o arquivo copiado terá um número adicionado ao seu nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos selecionados)",
    "({count} selected)" : "({count} selecionados)",
    "Error loading file exists template" : "Erro carregando arquivo. Já existe o modelo",
    "Saving …" : "Salvando...",
    "seconds ago" : "segundos atrás",
    "Connection to server lost" : "Conexão perdida com o servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n segundos","Problema no carregamento da página, recarregando em %n segundos"],
    "Add to a project" : "Adicionar a um projeto",
    "Show details" : "Mostrar detalhes",
    "Hide details" : "Ocultar detalhes",
    "Rename project" : "Renomear projeto",
    "Failed to rename the project" : "Erro ao renomear projeto",
    "Failed to create a project" : "Erro ao criar um projeto",
    "Failed to add the item to the project" : "Erro ao adicionar o item ao projeto",
    "Connect items to a project to make them easier to find" : "Conecte itens a um projeto para torná-los mais fáceis de encontrar",
    "Type to search for existing projects" : "Digite para pesquisar projetos existentes",
    "New in" : "Novo em",
    "View changelog" : "Ver alterações",
    "No action available" : "Nenhuma ação disponível",
    "Error fetching contact actions" : "Erro ao obter as ações de contato",
    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
    "Email length is at max (255)" : "O comprimento do e-mail é no máximo (255)",
    "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
    "Restricted" : "Restrita",
    "Invisible" : "Invisível",
    "Delete" : "Excluir",
    "Rename" : "Renomear",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "Nenhuma etiqueta encontrada",
    "Clipboard not available, please copy manually" : "Área de transferência não disponível, copie manualmente",
    "Personal" : "Pessoal",
    "Accounts" : "Contas",
    "Admin" : "Administrar",
    "Help" : "Ajuda",
    "Access forbidden" : "Acesso proibido",
    "Page not found" : "Página não encontrada",
    "The page could not be found on the server or you may not be allowed to view it." : "A página não pôde ser encontrada no servidor ou talvez você não tenha permissão para visualizá-la.",
    "Back to %s" : "Voltar para %s",
    "Too many requests" : "Muitas requisições",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houve muitas solicitações de sua rede. Tente novamente mais tarde ou entre em contato com o administrador se isso for um erro.",
    "Error" : "Erro",
    "Internal Server Error" : "Erro Interno do Servidor",
    "The server was unable to complete your request." : "O servidor não conseguiu completar sua solicitação.",
    "If this happens again, please send the technical details below to the server administrator." : "Se isso acontecer novamente, envie os detalhes técnicos abaixo para o administrador do servidor.",
    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
    "For more details see the documentation ↗." : "Para mais detalhes consulte a documentação ↗.",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "ID do Pedido: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensagem: %s",
    "File: %s" : "Arquivo: %s",
    "Line: %s" : "Linha: %s",
    "Trace" : "Rastreamento",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que você está tentando reinstalar o Nextcloud. No entanto, o arquivo CAN_INSTALL está faltando no diretório de configuração. Crie o arquivo CAN_INSTALL na pasta de configuração para continuar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Não foi possível remover CAN_INSTALL da pasta de configuração. Remova este arquivo manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Este aplicativo requer JavaScript para sua correta operação. Por favor {linkstart}habilite o JavaScript{linkend} e recarregue a página.",
    "Skip to main content" : "Ir ao conteúdo principal",
    "Skip to navigation of app" : "Ir à navegação do aplicativo",
    "Go to %s" : "Ir para %s",
    "Get your own free account" : "Obtenha uma conta grátis",
    "Connect to your account" : "Conectar à sua conta",
    "Please log in before granting %1$s access to your %2$s account." : "Logue-se antes de conceder acesso %1$s à sua conta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se você não está tentando configurar um novo dispositivo ou aplicativo, alguém está tentando induzi-lo a conceder acesso a seus dados. Nesse caso, não prossiga e entre em contato com o administrador do sistema.",
    "App password" : "Senha do aplicativo",
    "Grant access" : "Conceder acesso",
    "Alternative log in using app password" : "Login alternativo usando senha do aplicativo",
    "Account access" : "Acesso à conta",
    "Currently logged in as %1$s (%2$s)." : "Atualmente logado como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Você irá conceder acesso %1$s à sua conta %2$s.",
    "Account connected" : "Conta conectada",
    "Your client should now be connected!" : "Seu cliente deve estar conectado agora!",
    "You can close this window." : "Você pode fechar esta janela.",
    "Previous" : "Anterior",
    "This share is password-protected" : "Compartilhamento protegido por senha",
    "The password is wrong or expired. Please try again or request a new one." : "A senha está errada ou expirou. Tente novamente ou solicite uma nova.",
    "Please type in your email address to request a temporary password" : "Digite seu endereço de e-mail para solicitar uma senha temporária",
    "Email address" : "Endereço de e-mail",
    "Password sent!" : "Senha enviada!",
    "You are not authorized to request a password for this share" : "Você não está autorizado a solicitar uma senha para este compartilhamento",
    "Two-factor authentication" : "Autenticação de dois fatores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança aprimorada está ativada para sua conta. Escolha um segundo fator para autenticação:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar ao menos um dos métodos de autenticação de dois fatores ativados. Por favor, entre em contato com o administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "A autenticação de dois fatores foi aplicada, mas não foi configurada na sua conta. Entre em contato com o administrador para obter ajuda.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "A autenticação de dois fatores está aplicada, mas não foi configurada na sua conta. Por favor, continue a configurá-la.",
    "Set up two-factor authentication" : "Definir autenticação de dois fatores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "A autenticação de dois fatores está aplicada, mas não foi configurada na sua conta. Use um de seus códigos de backup para fazer login ou entre em contato com o administrador para obter ajuda.",
    "Use backup code" : "Use o código de backup",
    "Cancel login" : "Cancelar o login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "A segurança aprimorada é aplicada à sua conta. Escolha qual provedor configurar:",
    "Error while validating your second factor" : "Erro ao validar o segundo fator",
    "Access through untrusted domain" : "Acessar através de um domínio inseguro",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte seu administrador. Se você for o administrador, edite a configuração \"trusted_domains\" em config/config.php como o exemplo em config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informações de como configurar isso podem ser encontradas na %1$sdocumentação%2$s.",
    "App update required" : "Atualização de aplicativo é necessária",
    "%1$s will be updated to version %2$s" : "%1$s será atualizado para a versão %2$s",
    "The following apps will be updated:" : "Os seguintes aplicativos serão atualizados:",
    "These incompatible apps will be disabled:" : "Estes aplicativos incompatíveis serão desabilitados:",
    "The theme %s has been disabled." : "O tema %s foi desativado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que o banco de dados, a pasta config e a pasta de dados foram copiados antes de prosseguir.",
    "Start update" : "Iniciar atualização",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar atingir o tempo limite em instalações maiores, você pode em vez disso executar o seguinte comando a partir do diretório de instalação:",
    "Detailed logs" : "Logs detalhados",
    "Update needed" : "Atualização necessária",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Por favor, use o atualizador de linha de comando porque você tem uma grande instância com mais de 50 contas.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Precisando de ajuda, leia a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar atualizando pela interfaceweb, há o risco de atingir o tempo limite e ocorrer perda de dados mas eu tenho um cópia de backup e sei como restaurar meu sistema se isso ocorrer.",
    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco",
    "Maintenance mode" : "Modo de manutenção",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
    "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
    "Currently open" : "Atualmente aberto",
    "Login with username or email" : "Login com nome de usuário ou e-mail",
    "Login with username" : "Login com nome de usuário",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões online e conferência na web - no seu navegador e com aplicativos móveis.",
    "You have not added any info yet" : "Você ainda não adicionou nenhuma informação",
    "{user} has not added any info yet" : "{user} ainda não adicionou nenhuma informação",
    "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de status do usuário, tente atualizar a página",
    "Edit Profile" : "Editar Perfil ",
    "The headline and about sections will show up here" : "O título e as seções sobre serão exibidos aqui",
    "Error loading message template: {error}" : "Erro carregando o modelo de mensagem: {error}",
    "Very weak password" : "Senha muito fraca",
    "Weak password" : "Senha fraca",
    "So-so password" : "Senha mais ou menos",
    "Good password" : "Senha boa",
    "Strong password" : "Senha forte",
    "Profile not found" : "Perfil não encontrado",
    "The profile does not exist." : "O perfil não existe. ",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Criar uma conta de administrador</strong>",
    "New admin account name" : "Nome de conta do novo Administrador",
    "New admin password" : "Senha do novo Administrador",
    "Show password" : "Mostrar senha",
    "Toggle password visibility" : "Alternar visibilidade da senha",
    "Configure the database" : "Configurar o banco de dados",
    "Only %s is available." : "Somente %s está disponível.",
    "Database account" : "Conta de banco de dados"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
